#[repr(C)]pub struct SdmmcRegisterInBandInterruptRequest {
pub interrupt_cb: ClientEnd<InBandInterrupt, DriverChannel>,
}Fields
interrupt_cb: ClientEnd<InBandInterrupt, DriverChannel>Trait Implementations
Sourceimpl<___E> Encode<SdmmcRegisterInBandInterruptRequest, ___E> for SdmmcRegisterInBandInterruptRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<SdmmcRegisterInBandInterruptRequest, ___E> for SdmmcRegisterInBandInterruptRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SdmmcRegisterInBandInterruptRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, SdmmcRegisterInBandInterruptRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcRegisterInBandInterruptRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcRegisterInBandInterruptRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, SdmmcRegisterInBandInterruptRequest>, ___E> for SdmmcRegisterInBandInterruptRequestwhere
___E: Encoder + ?Sized,
SdmmcRegisterInBandInterruptRequest: Encode<SdmmcRegisterInBandInterruptRequest, ___E>,
impl<___E> EncodeOption<Box<'static, SdmmcRegisterInBandInterruptRequest>, ___E> for SdmmcRegisterInBandInterruptRequestwhere
___E: Encoder + ?Sized,
SdmmcRegisterInBandInterruptRequest: Encode<SdmmcRegisterInBandInterruptRequest, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SdmmcRegisterInBandInterruptRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SdmmcRegisterInBandInterruptRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<SdmmcRegisterInBandInterruptRequest> for SdmmcRegisterInBandInterruptRequest
impl FromWire<SdmmcRegisterInBandInterruptRequest> for SdmmcRegisterInBandInterruptRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SdmmcRegisterInBandInterruptRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<SdmmcRegisterInBandInterruptRequest, Self>
Sourcefn from_wire(wire: SdmmcRegisterInBandInterruptRequest) -> Self
fn from_wire(wire: SdmmcRegisterInBandInterruptRequest) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for SdmmcRegisterInBandInterruptRequest
impl PartialEq for SdmmcRegisterInBandInterruptRequest
Sourcefn eq(&self, other: &SdmmcRegisterInBandInterruptRequest) -> bool
fn eq(&self, other: &SdmmcRegisterInBandInterruptRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SdmmcRegisterInBandInterruptRequest