pub struct SdmmcHostPrefs(/* private fields */);Implementations
Sourceimpl SdmmcHostPrefs
impl SdmmcHostPrefs
pub const DISABLE_HS400: SdmmcHostPrefs
pub const DISABLE_HS200: SdmmcHostPrefs
pub const DISABLE_HSDDR: SdmmcHostPrefs
Sourceimpl SdmmcHostPrefs
impl SdmmcHostPrefs
Sourcepub const fn empty() -> SdmmcHostPrefs
pub const fn empty() -> SdmmcHostPrefs
Get a flags value with all bits unset.
Sourcepub const fn all() -> SdmmcHostPrefs
pub const fn all() -> SdmmcHostPrefs
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<SdmmcHostPrefs>
pub const fn from_bits(bits: u64) -> Option<SdmmcHostPrefs>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> SdmmcHostPrefs
pub const fn from_bits_truncate(bits: u64) -> SdmmcHostPrefs
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> SdmmcHostPrefs
pub const fn from_bits_retain(bits: u64) -> SdmmcHostPrefs
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SdmmcHostPrefs>
pub fn from_name(name: &str) -> Option<SdmmcHostPrefs>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SdmmcHostPrefs) -> bool
pub const fn intersects(&self, other: SdmmcHostPrefs) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: SdmmcHostPrefs) -> bool
pub const fn contains(&self, other: SdmmcHostPrefs) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: SdmmcHostPrefs)
pub fn insert(&mut self, other: SdmmcHostPrefs)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: SdmmcHostPrefs)
pub fn remove(&mut self, other: SdmmcHostPrefs)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SdmmcHostPrefs)
pub fn toggle(&mut self, other: SdmmcHostPrefs)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: SdmmcHostPrefs, value: bool)
pub fn set(&mut self, other: SdmmcHostPrefs, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SdmmcHostPrefs) -> SdmmcHostPrefs
pub const fn intersection(self, other: SdmmcHostPrefs) -> SdmmcHostPrefs
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: SdmmcHostPrefs) -> SdmmcHostPrefs
pub const fn union(self, other: SdmmcHostPrefs) -> SdmmcHostPrefs
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: SdmmcHostPrefs) -> SdmmcHostPrefs
pub const fn difference(self, other: SdmmcHostPrefs) -> SdmmcHostPrefs
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: SdmmcHostPrefs) -> SdmmcHostPrefs
pub const fn symmetric_difference(self, other: SdmmcHostPrefs) -> SdmmcHostPrefs
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> SdmmcHostPrefs
pub const fn complement(self) -> SdmmcHostPrefs
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl SdmmcHostPrefs
impl SdmmcHostPrefs
Sourcepub const fn iter(&self) -> Iter<SdmmcHostPrefs>
pub const fn iter(&self) -> Iter<SdmmcHostPrefs>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SdmmcHostPrefs>
pub const fn iter_names(&self) -> IterNames<SdmmcHostPrefs>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.