pub struct SdmmcVmoRight(/* private fields */);Implementations
Sourceimpl SdmmcVmoRight
impl SdmmcVmoRight
pub const READ: SdmmcVmoRight
pub const WRITE: SdmmcVmoRight
Sourceimpl SdmmcVmoRight
impl SdmmcVmoRight
Sourcepub const fn empty() -> SdmmcVmoRight
pub const fn empty() -> SdmmcVmoRight
Get a flags value with all bits unset.
Sourcepub const fn all() -> SdmmcVmoRight
pub const fn all() -> SdmmcVmoRight
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<SdmmcVmoRight>
pub const fn from_bits(bits: u32) -> Option<SdmmcVmoRight>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> SdmmcVmoRight
pub const fn from_bits_truncate(bits: u32) -> SdmmcVmoRight
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> SdmmcVmoRight
pub const fn from_bits_retain(bits: u32) -> SdmmcVmoRight
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SdmmcVmoRight>
pub fn from_name(name: &str) -> Option<SdmmcVmoRight>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SdmmcVmoRight) -> bool
pub const fn intersects(&self, other: SdmmcVmoRight) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: SdmmcVmoRight) -> bool
pub const fn contains(&self, other: SdmmcVmoRight) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: SdmmcVmoRight)
pub fn insert(&mut self, other: SdmmcVmoRight)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: SdmmcVmoRight)
pub fn remove(&mut self, other: SdmmcVmoRight)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SdmmcVmoRight)
pub fn toggle(&mut self, other: SdmmcVmoRight)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: SdmmcVmoRight, value: bool)
pub fn set(&mut self, other: SdmmcVmoRight, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SdmmcVmoRight) -> SdmmcVmoRight
pub const fn intersection(self, other: SdmmcVmoRight) -> SdmmcVmoRight
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: SdmmcVmoRight) -> SdmmcVmoRight
pub const fn union(self, other: SdmmcVmoRight) -> SdmmcVmoRight
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: SdmmcVmoRight) -> SdmmcVmoRight
pub const fn difference(self, other: SdmmcVmoRight) -> SdmmcVmoRight
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: SdmmcVmoRight) -> SdmmcVmoRight
pub const fn symmetric_difference(self, other: SdmmcVmoRight) -> SdmmcVmoRight
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> SdmmcVmoRight
pub const fn complement(self) -> SdmmcVmoRight
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl SdmmcVmoRight
impl SdmmcVmoRight
Sourcepub const fn iter(&self) -> Iter<SdmmcVmoRight>
pub const fn iter(&self) -> Iter<SdmmcVmoRight>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SdmmcVmoRight>
pub const fn iter_names(&self) -> IterNames<SdmmcVmoRight>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.