#[repr(C)]pub struct SdmmcRegisterVmoRequest {
pub vmo_id: Uint32,
pub client_id: u8,
pub vmo: Vmo,
pub offset: Uint64,
pub size: Uint64,
pub vmo_rights: SdmmcVmoRight,
}Expand description
The wire type corresponding to SdmmcRegisterVmoRequest.
Fields
vmo_id: Uint32client_id: u8vmo: Vmooffset: Uint64size: Uint64vmo_rights: SdmmcVmoRightTrait Implementations
Sourceimpl Constrained for SdmmcRegisterVmoRequest
impl Constrained for SdmmcRegisterVmoRequest
Sourceimpl Debug for SdmmcRegisterVmoRequest
impl Debug for SdmmcRegisterVmoRequest
Sourceimpl<___D> Decode<___D> for SdmmcRegisterVmoRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for SdmmcRegisterVmoRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<SdmmcRegisterVmoRequest, ___E> for SdmmcRegisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<SdmmcRegisterVmoRequest, ___E> for SdmmcRegisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcRegisterVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcRegisterVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2, T3, T4, T5> Encode<SdmmcRegisterVmoRequest, ___E> for SdmmcRegisterVmoRequest<T0, T1, T2, T3, T4, T5>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Uint32, ___E>,
T1: Encode<u8, ___E>,
T2: Encode<Vmo, ___E>,
T3: Encode<Uint64, ___E>,
T4: Encode<Uint64, ___E>,
T5: Encode<SdmmcVmoRight, ___E>,
impl<___E, T0, T1, T2, T3, T4, T5> Encode<SdmmcRegisterVmoRequest, ___E> for SdmmcRegisterVmoRequest<T0, T1, T2, T3, T4, T5>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Uint32, ___E>,
T1: Encode<u8, ___E>,
T2: Encode<Vmo, ___E>,
T3: Encode<Uint64, ___E>,
T4: Encode<Uint64, ___E>,
T5: Encode<SdmmcVmoRight, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcRegisterVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcRegisterVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SdmmcRegisterVmoRequest> for SdmmcRegisterVmoRequest
impl FromWire<SdmmcRegisterVmoRequest> for SdmmcRegisterVmoRequest
Sourcefn from_wire(wire: SdmmcRegisterVmoRequest) -> Self
fn from_wire(wire: SdmmcRegisterVmoRequest) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl IntoNatural for SdmmcRegisterVmoRequest
impl IntoNatural for SdmmcRegisterVmoRequest
Sourcetype Natural = SdmmcRegisterVmoRequest
type Natural = SdmmcRegisterVmoRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SdmmcRegisterVmoRequest
impl Wire for SdmmcRegisterVmoRequest
Sourcetype Narrowed<'de> = SdmmcRegisterVmoRequest
type Narrowed<'de> = SdmmcRegisterVmoRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.