#[repr(C)]pub struct SdmmcRequestRequest<'de> {
pub reqs: Vector<'de, SdmmcReq<'de>>,
}Expand description
The wire type corresponding to SdmmcRequestRequest.
Fields
reqs: Vector<'de, SdmmcReq<'de>>Trait Implementations
Sourceimpl Constrained for SdmmcRequestRequest<'_>
impl Constrained for SdmmcRequestRequest<'_>
Sourceimpl<'de> Debug for SdmmcRequestRequest<'de>
impl<'de> Debug for SdmmcRequestRequest<'de>
Sourceimpl<'de, ___D> Decode<___D> for SdmmcRequestRequest<'de>where
___D: InternalHandleDecoder + ?Sized + Decoder<'de> + HandleDecoder,
impl<'de, ___D> Decode<___D> for SdmmcRequestRequest<'de>where
___D: InternalHandleDecoder + ?Sized + Decoder<'de> + HandleDecoder,
Sourceimpl<___E> Encode<SdmmcRequestRequest<'static>, ___E> for SdmmcRequestRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<SdmmcRequestRequest<'static>, ___E> for SdmmcRequestRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcRequestRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcRequestRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<SdmmcRequestRequest<'static>, ___E> for SdmmcRequestRequest<T0>
impl<___E, T0> Encode<SdmmcRequestRequest<'static>, ___E> for SdmmcRequestRequest<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcRequestRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcRequestRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<SdmmcRequestRequest<'de>> for SdmmcRequestRequest
impl<'de> FromWire<SdmmcRequestRequest<'de>> for SdmmcRequestRequest
Sourcefn from_wire(wire: SdmmcRequestRequest<'de>) -> Self
fn from_wire(wire: SdmmcRequestRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> IntoNatural for SdmmcRequestRequest<'de>
impl<'de> IntoNatural for SdmmcRequestRequest<'de>
Sourcetype Natural = SdmmcRequestRequest
type Natural = SdmmcRequestRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SdmmcRequestRequest<'static>
impl Wire for SdmmcRequestRequest<'static>
Sourcetype Narrowed<'de> = SdmmcRequestRequest<'de>
type Narrowed<'de> = SdmmcRequestRequest<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.