#[repr(C)]pub struct SdmmcRequestResponse {
pub response: [Uint32; 4],
}Expand description
The wire type corresponding to SdmmcRequestResponse.
Fields
response: [Uint32; 4]Trait Implementations
Sourceimpl Clone for SdmmcRequestResponse
impl Clone for SdmmcRequestResponse
Sourcefn clone(&self) -> SdmmcRequestResponse
fn clone(&self) -> SdmmcRequestResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SdmmcRequestResponse
impl Constrained for SdmmcRequestResponse
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, SdmmcRequestResponse>,
_: <SdmmcRequestResponse as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, SdmmcRequestResponse>, _: <SdmmcRequestResponse as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for SdmmcRequestResponse
impl Debug for SdmmcRequestResponse
Sourceimpl<___D> Decode<___D> for SdmmcRequestResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SdmmcRequestResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<SdmmcRequestResponse, ___E> for &'a SdmmcRequestResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SdmmcRequestResponse, ___E> for &'a SdmmcRequestResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcRequestResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcRequestResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SdmmcRequestResponse, ___E> for SdmmcRequestResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SdmmcRequestResponse, ___E> for SdmmcRequestResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SdmmcRequestResponse, SdmmcRequestResponse>
const COPY_OPTIMIZATION: CopyOptimization<SdmmcRequestResponse, SdmmcRequestResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcRequestResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcRequestResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<SdmmcRequestResponse, ___E> for SdmmcRequestResponse<T0>
impl<___E, T0> Encode<SdmmcRequestResponse, ___E> for SdmmcRequestResponse<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcRequestResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcRequestResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SdmmcRequestResponse> for SdmmcRequestResponse
impl FromWire<SdmmcRequestResponse> for SdmmcRequestResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SdmmcRequestResponse, SdmmcRequestResponse>
const COPY_OPTIMIZATION: CopyOptimization<SdmmcRequestResponse, SdmmcRequestResponse>
Sourcefn from_wire(wire: SdmmcRequestResponse) -> SdmmcRequestResponse
fn from_wire(wire: SdmmcRequestResponse) -> SdmmcRequestResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<SdmmcRequestResponse> for SdmmcRequestResponse
impl FromWireRef<SdmmcRequestResponse> for SdmmcRequestResponse
Sourcefn from_wire_ref(wire: &SdmmcRequestResponse) -> SdmmcRequestResponse
fn from_wire_ref(wire: &SdmmcRequestResponse) -> SdmmcRequestResponse
Converts the given reference to this type.
Sourceimpl IntoNatural for SdmmcRequestResponse
impl IntoNatural for SdmmcRequestResponse
Sourcetype Natural = SdmmcRequestResponse
type Natural = SdmmcRequestResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SdmmcRequestResponse
impl Wire for SdmmcRequestResponse
Sourcetype Narrowed<'de> = SdmmcRequestResponse
type Narrowed<'de> = SdmmcRequestResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<SdmmcRequestResponse>)
fn zero_padding(out_: &mut MaybeUninit<SdmmcRequestResponse>)
Writes zeroes to the padding for this type, if any.