#[repr(C)]pub struct SdmmcUnregisterVmoResponse {
pub vmo: Vmo,
}Expand description
The wire type corresponding to SdmmcUnregisterVmoResponse.
Fields
vmo: VmoTrait Implementations
Sourceimpl Constrained for SdmmcUnregisterVmoResponse
impl Constrained for SdmmcUnregisterVmoResponse
Sourceimpl Debug for SdmmcUnregisterVmoResponse
impl Debug for SdmmcUnregisterVmoResponse
Sourceimpl<___D> Decode<___D> for SdmmcUnregisterVmoResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for SdmmcUnregisterVmoResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<SdmmcUnregisterVmoResponse, ___E> for SdmmcUnregisterVmoResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<SdmmcUnregisterVmoResponse, ___E> for SdmmcUnregisterVmoResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SdmmcUnregisterVmoResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, SdmmcUnregisterVmoResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcUnregisterVmoResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcUnregisterVmoResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<SdmmcUnregisterVmoResponse, ___E> for SdmmcUnregisterVmoResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Vmo, ___E>,
impl<___E, T0> Encode<SdmmcUnregisterVmoResponse, ___E> for SdmmcUnregisterVmoResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Vmo, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcUnregisterVmoResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcUnregisterVmoResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SdmmcUnregisterVmoResponse> for SdmmcUnregisterVmoResponse
impl FromWire<SdmmcUnregisterVmoResponse> for SdmmcUnregisterVmoResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SdmmcUnregisterVmoResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<SdmmcUnregisterVmoResponse, Self>
Sourcefn from_wire(wire: SdmmcUnregisterVmoResponse) -> Self
fn from_wire(wire: SdmmcUnregisterVmoResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for SdmmcUnregisterVmoResponse
impl IntoNatural for SdmmcUnregisterVmoResponse
Sourcetype Natural = SdmmcUnregisterVmoResponse
type Natural = SdmmcUnregisterVmoResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SdmmcUnregisterVmoResponse
impl Wire for SdmmcUnregisterVmoResponse
Sourcetype Narrowed<'de> = SdmmcUnregisterVmoResponse
type Narrowed<'de> = SdmmcUnregisterVmoResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.